==> nextcloud-15.0.5p1.tgz: nextcloud/apps/survey_client/l10n/sl.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Poročilo o uporabi",
    "Last report sent on: {on}" : "Nazadnje poslano poročilo: {on}",
    "An error occurred while sending your report." : "Med pošiljanjem poročila je prišlo do napake.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Seznam programov <em>(za vsak program: ime, različica, stanje)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Podatkovno okolje <em>(vrsta, različica, velikost podatkovne zbirke)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Podatki o vrsti šifriranja <em>(omogočeni moduli, privzete nastavitve)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Število predmetov v souporabi <em>(vrste, nastavitve dovoljenj)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Okolje PHP <em>(različica, omejitev pomnilnika, največji čas izvajanja, omejitev velikosti datotek)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Podrobnosti strežnika <em>(različica, uporabljen memcache, stanje zaklepa/predogleda/uporabljene podobe)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Statistika <em>(število datotek, število uporabnikov, omejitev shrambe, opombe, oznake)</em>",
    "Help improve Nextcloud" : "Sodelujte pri izboljševanju oblaka Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Ali bi želeli sodelovati pri izboljševanju okolja Nextcloud s pošiljanjem anonimiziranih podatkov o nastavitvah in uporabi? Nastavitev lahko kadarkoli onemogočite skrbniškimi med nastavitvami.",
    "Not now" : "Ne zdaj",
    "Send usage" : "Pošlji poročilo",
    "Never" : "Nikoli ne pošlji",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Pošljite anonimizirane podatke in s tem pomagajte pri izboljševanju okolja Nextcloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Pošljite anonimizirane podatke uporabe za pomoč pri izboljševanju okolja Nextcloud.\n        Vedno imate popoln nadzor nad vsebino poročil in možnost prilagajanja\n        načina in časa pošiljanja.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Lahko sodelujete pri izboljševanju okolja Nextcloud s pošiljanjem izbranih podatkov o trenutnih nastavitvah in načinu uporabe.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Zasebnost jemljemo resno. Pošiljanje poročil je privzeto onemogočeno, če možnost omogočite pa bodo podatki najprej anonimizirani, prav tako lahko izberete, katere podatke bi želeli poslati. Po prejetju poročila se vsa starejša izbrišejo, vsi stari podatki pa se na strežniku posodobijo na zadnje vrednosti.",
    "Send new report now" : "Pošlji novo poročilo takoj",
    "Send usage survey monthly" : "Pošlji poročilo o uporabi enkrat mesečno",
    "Data to send" : "Podatki v poročilu",
    "Last report sent on: %s" : "Nazadnje poslano poročilo: %s",
    "Last report" : "Zadnje poročilo",
    "Sent on: {on}" : "Poslano: {on}",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistika <em>(število datotek, število uporabnikov, omejitev shrambe, opombe, oznake)</em>",
    "Sent on: %s" : "Poslano: %s"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-23.0.8.tgz: nextcloud/apps/survey_client/l10n/sl.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Nazadnje poslano poročilo: {on}",
    "An error occurred while sending your report." : "Med pošiljanjem poročila je prišlo do napake.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Seznam programov <em>(za vsak program: ime, različica, stanje)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Podatkovno okolje <em>(vrsta, različica, velikost podatkovne zbirke)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Podatki o vrsti šifriranja <em>(omogočeni moduli, privzete nastavitve)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Število predmetov v souporabi <em>(vrste, nastavitve dovoljenj)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Okolje PHP <em>(različica, omejitev pomnilnika, največji čas izvajanja, omejitev velikosti datotek)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Podrobnosti strežnika <em>(različica, uporabljen memcache, stanje zaklepa/predogleda/uporabljene podobe)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Statistika <em>(število datotek, število uporabnikov, omejitev shrambe, opombe, oznake)</em>",
    "Usage survey" : "Poročilo o uporabi",
    "Help improve Nextcloud" : "Sodelujte pri izboljševanju oblaka Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Ali bi želeli sodelovati pri izboljševanju okolja Nextcloud s pošiljanjem anonimiziranih podatkov o nastavitvah in uporabi? Nastavitev lahko kadarkoli onemogočite med skrbniškimi nastavitvami.",
    "Not now" : "Ne zdaj",
    "Send usage" : "Pošlji poročilo",
    "Never" : "Nikoli ne pošlji",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Pošljite anonimizirane podatke in s tem pomagajte pri izboljševanju okolja Nextcloud.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Lahko sodelujete pri izboljševanju okolja Nextcloud s pošiljanjem izbranih podatkov o trenutnih nastavitvah in načinu uporabe.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Zasebnost jemljemo resno. Pošiljanje poročil je privzeto onemogočeno, če možnost omogočite pa bodo podatki najprej anonimizirani, prav tako lahko izberete, katere podatke bi želeli poslati. Po prejetju poročila se vsa starejša izbrišejo, vsi stari podatki pa se na strežniku posodobijo na zadnje vrednosti.",
    "Send new report now" : "Pošlji novo poročilo takoj",
    "Send usage survey monthly" : "Pošlji poročilo o uporabi enkrat mesečno",
    "Data to send" : "Podatki v poročilu",
    "Last report sent on: %s" : "Nazadnje poslano poročilo: %s",
    "Last report" : "Zadnje poročilo",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Pošljite anonimizirane podatke uporabe za pomoč pri izboljševanju okolja Nextcloud.\n        Vedno imate popoln nadzor nad vsebino poročil in možnost prilagajanja\n        načina in časa pošiljanja."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
